```
Usage: vcd gateway services firewall list-objects [OPTIONS] <gateway name>

Options:
  --type <source/destination>  type. possible value will be source/destination
                               [required]
  --object-type <object type>  object type  [required]
  -h, --help                   Show this message and exit.

```
